@@ -31,9 +31,6 @@
 #include <libgnome/gnome-config.h>
 #include <libgnomeui/gnome-client.h>
 
-#define totem_signal_block_by_data(obj, data) (g_signal_handlers_block_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
-#define totem_signal_unblock_by_data(obj, data) (g_signal_handlers_unblock_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
-
 static char *
 totem_session_create_key (void)
 {
